@@ -14,7 +14,7 @@ translogEla <- function( xNames, data, coef, coefCov = NULL,
    if( dataLogged ) {
       logData <- data
    } else {
-      logData <- .micEconLogData( data = data, 
+      logData <- logDataSet( data = data,
          varNames = xNames )
    }
 
